pub struct ProcessingStep {
pub matcher: Arc<dyn Matcher>,
pub mailet: Arc<dyn Mailet>,
pub config: MailetConfig,
}Expand description
Matcher-Mailet pair with optional per-step configuration
Fields
matcher: Arc<dyn Matcher>mailet: Arc<dyn Mailet>config: MailetConfigPer-step mailet configuration (timeout, error policy)
Implementations
Sourceimpl ProcessingStep
impl ProcessingStep
Sourcepub fn new(matcher: Arc<dyn Matcher>, mailet: Arc<dyn Mailet>) -> Self
pub fn new(matcher: Arc<dyn Matcher>, mailet: Arc<dyn Mailet>) -> Self
Create a new processing step with a default config derived from the mailet name
Sourcepub fn new_with_config(
matcher: Arc<dyn Matcher>,
mailet: Arc<dyn Mailet>,
config: MailetConfig,
) -> Self
pub fn new_with_config( matcher: Arc<dyn Matcher>, mailet: Arc<dyn Mailet>, config: MailetConfig, ) -> Self
Create a new processing step with an explicit configuration